# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class WebhookResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'events': 'list[str]',
        'name': 'str',
        'secret': 'str',
        'status': 'str',
        'url': 'str',
        'wh_uuid': 'str'
    }

    attribute_map = {
        'events': 'events',
        'name': 'name',
        'secret': 'secret',
        'status': 'status',
        'url': 'url',
        'wh_uuid': 'wh_uuid'
    }

    def __init__(self, events=None, name=None, secret=None, status=None, url=None, wh_uuid=None):  # noqa: E501
        """WebhookResponse - a model defined in Swagger"""  # noqa: E501
        self._events = None
        self._name = None
        self._secret = None
        self._status = None
        self._url = None
        self._wh_uuid = None
        self.discriminator = None
        if events is not None:
            self.events = events
        if name is not None:
            self.name = name
        if secret is not None:
            self.secret = secret
        if status is not None:
            self.status = status
        if url is not None:
            self.url = url
        if wh_uuid is not None:
            self.wh_uuid = wh_uuid

    @property
    def events(self):
        """Gets the events of this WebhookResponse.  # noqa: E501

        Tipos de eventos de los cuales Wire4 te enviará información.  # noqa: E501

        :return: The events of this WebhookResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this WebhookResponse.

        Tipos de eventos de los cuales Wire4 te enviará información.  # noqa: E501

        :param events: The events of this WebhookResponse.  # noqa: E501
        :type: list[str]
        """

        self._events = events

    @property
    def name(self):
        """Gets the name of this WebhookResponse.  # noqa: E501

        Es el nombre del webhook.  # noqa: E501

        :return: The name of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WebhookResponse.

        Es el nombre del webhook.  # noqa: E501

        :param name: The name of this WebhookResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def secret(self):
        """Gets the secret of this WebhookResponse.  # noqa: E501

        Llave con la cual se debe de identificar que el webhook fue enviado por Wire4, para mayor información revisar la guía de notificaciones (https://wire4.mx/#/guides/notificaciones),  en la sección de  <a href=\"https://wire4.mx/#/guides/notificaciones\">\"Comprobación de firmas de Webhook\".</a>  # noqa: E501

        :return: The secret of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this WebhookResponse.

        Llave con la cual se debe de identificar que el webhook fue enviado por Wire4, para mayor información revisar la guía de notificaciones (https://wire4.mx/#/guides/notificaciones),  en la sección de  <a href=\"https://wire4.mx/#/guides/notificaciones\">\"Comprobación de firmas de Webhook\".</a>  # noqa: E501

        :param secret: The secret of this WebhookResponse.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def status(self):
        """Gets the status of this WebhookResponse.  # noqa: E501

        Es el estado (estatus) en el que se encuentra el webhook.  # noqa: E501

        :return: The status of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WebhookResponse.

        Es el estado (estatus) en el que se encuentra el webhook.  # noqa: E501

        :param status: The status of this WebhookResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE", "DELETED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def url(self):
        """Gets the url of this WebhookResponse.  # noqa: E501

        Es la dirección URL a la que Wire4 enviará las notificaciones cuando un evento ocurra.  # noqa: E501

        :return: The url of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WebhookResponse.

        Es la dirección URL a la que Wire4 enviará las notificaciones cuando un evento ocurra.  # noqa: E501

        :param url: The url of this WebhookResponse.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def wh_uuid(self):
        """Gets the wh_uuid of this WebhookResponse.  # noqa: E501

        Es el identificador del webhook. Ejemplo: wh_54a832866f784b439bc625c0f4e04e12.  # noqa: E501

        :return: The wh_uuid of this WebhookResponse.  # noqa: E501
        :rtype: str
        """
        return self._wh_uuid

    @wh_uuid.setter
    def wh_uuid(self, wh_uuid):
        """Sets the wh_uuid of this WebhookResponse.

        Es el identificador del webhook. Ejemplo: wh_54a832866f784b439bc625c0f4e04e12.  # noqa: E501

        :param wh_uuid: The wh_uuid of this WebhookResponse.  # noqa: E501
        :type: str
        """

        self._wh_uuid = wh_uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.account_response import AccountResponse  # noqa: F401,E501


class BeneficiariesQueryRegisterStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'authorization_date': 'datetime',
        'beneficiaries': 'list[AccountResponse]',
        'request_date': 'datetime',
        'request_id': 'str',
        'status_request': 'str',
        'total_beneficiaries': 'int'
    }

    attribute_map = {
        'authorization_date': 'authorization_date',
        'beneficiaries': 'beneficiaries',
        'request_date': 'request_date',
        'request_id': 'request_id',
        'status_request': 'status_request',
        'total_beneficiaries': 'total_beneficiaries'
    }

    def __init__(self, authorization_date=None, beneficiaries=None, request_date=None, request_id=None, status_request=None, total_beneficiaries=None):  # noqa: E501
        """BeneficiariesQueryRegisterStatus - a model defined in Swagger"""  # noqa: E501
        self._authorization_date = None
        self._beneficiaries = None
        self._request_date = None
        self._request_id = None
        self._status_request = None
        self._total_beneficiaries = None
        self.discriminator = None
        if authorization_date is not None:
            self.authorization_date = authorization_date
        if beneficiaries is not None:
            self.beneficiaries = beneficiaries
        if request_date is not None:
            self.request_date = request_date
        if request_id is not None:
            self.request_id = request_id
        if status_request is not None:
            self.status_request = status_request
        if total_beneficiaries is not None:
            self.total_beneficiaries = total_beneficiaries

    @property
    def authorization_date(self):
        """Gets the authorization_date of this BeneficiariesQueryRegisterStatus.  # noqa: E501

        Fecha en que el usuario propietario del token autorizo el registro de beneficiarios  # noqa: E501

        :return: The authorization_date of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._authorization_date

    @authorization_date.setter
    def authorization_date(self, authorization_date):
        """Sets the authorization_date of this BeneficiariesQueryRegisterStatus.

        Fecha en que el usuario propietario del token autorizo el registro de beneficiarios  # noqa: E501

        :param authorization_date: The authorization_date of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :type: datetime
        """

        self._authorization_date = authorization_date

    @property
    def beneficiaries(self):
        """Gets the beneficiaries of this BeneficiariesQueryRegisterStatus.  # noqa: E501

        Es una lista de beneficiarios obtenidos.  # noqa: E501

        :return: The beneficiaries of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :rtype: list[AccountResponse]
        """
        return self._beneficiaries

    @beneficiaries.setter
    def beneficiaries(self, beneficiaries):
        """Sets the beneficiaries of this BeneficiariesQueryRegisterStatus.

        Es una lista de beneficiarios obtenidos.  # noqa: E501

        :param beneficiaries: The beneficiaries of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :type: list[AccountResponse]
        """

        self._beneficiaries = beneficiaries

    @property
    def request_date(self):
        """Gets the request_date of this BeneficiariesQueryRegisterStatus.  # noqa: E501

        Fecha en que se realizó la petición de registro de beneficiarios,   # noqa: E501

        :return: The request_date of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._request_date

    @request_date.setter
    def request_date(self, request_date):
        """Sets the request_date of this BeneficiariesQueryRegisterStatus.

        Fecha en que se realizó la petición de registro de beneficiarios,   # noqa: E501

        :param request_date: The request_date of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :type: datetime
        """

        self._request_date = request_date

    @property
    def request_id(self):
        """Gets the request_id of this BeneficiariesQueryRegisterStatus.  # noqa: E501

        Identificador de la petición del registro de beneficiarios  # noqa: E501

        :return: The request_id of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this BeneficiariesQueryRegisterStatus.

        Identificador de la petición del registro de beneficiarios  # noqa: E501

        :param request_id: The request_id of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def status_request(self):
        """Gets the status_request of this BeneficiariesQueryRegisterStatus.  # noqa: E501

        Indica sí la petición ya fue autorizada usando el token del usuario  # noqa: E501

        :return: The status_request of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :rtype: str
        """
        return self._status_request

    @status_request.setter
    def status_request(self, status_request):
        """Sets the status_request of this BeneficiariesQueryRegisterStatus.

        Indica sí la petición ya fue autorizada usando el token del usuario  # noqa: E501

        :param status_request: The status_request of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :type: str
        """
        allowed_values = ["PENDING", "AUTHORIZED"]  # noqa: E501
        if status_request not in allowed_values:
            raise ValueError(
                "Invalid value for `status_request` ({0}), must be one of {1}"  # noqa: E501
                .format(status_request, allowed_values)
            )

        self._status_request = status_request

    @property
    def total_beneficiaries(self):
        """Gets the total_beneficiaries of this BeneficiariesQueryRegisterStatus.  # noqa: E501

        Total de beneficiarios enviados en la petición  # noqa: E501

        :return: The total_beneficiaries of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :rtype: int
        """
        return self._total_beneficiaries

    @total_beneficiaries.setter
    def total_beneficiaries(self, total_beneficiaries):
        """Sets the total_beneficiaries of this BeneficiariesQueryRegisterStatus.

        Total de beneficiarios enviados en la petición  # noqa: E501

        :param total_beneficiaries: The total_beneficiaries of this BeneficiariesQueryRegisterStatus.  # noqa: E501
        :type: int
        """

        self._total_beneficiaries = total_beneficiaries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BeneficiariesQueryRegisterStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BeneficiariesQueryRegisterStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AuthorizedUsers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account': 'str',
        'masked_account': 'str',
        'masked_name': 'str',
        'masked_user_name': 'str',
        'name': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'account': 'account',
        'masked_account': 'masked_account',
        'masked_name': 'masked_name',
        'masked_user_name': 'masked_user_name',
        'name': 'name',
        'user_name': 'user_name'
    }

    def __init__(self, account=None, masked_account=None, masked_name=None, masked_user_name=None, name=None, user_name=None):  # noqa: E501
        """AuthorizedUsers - a model defined in Swagger"""  # noqa: E501
        self._account = None
        self._masked_account = None
        self._masked_name = None
        self._masked_user_name = None
        self._name = None
        self._user_name = None
        self.discriminator = None
        if account is not None:
            self.account = account
        if masked_account is not None:
            self.masked_account = masked_account
        if masked_name is not None:
            self.masked_name = masked_name
        if masked_user_name is not None:
            self.masked_user_name = masked_user_name
        if name is not None:
            self.name = name
        if user_name is not None:
            self.user_name = user_name

    @property
    def account(self):
        """Gets the account of this AuthorizedUsers.  # noqa: E501

        El contrato al cual se le brinda el acceso a la API  # noqa: E501

        :return: The account of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this AuthorizedUsers.

        El contrato al cual se le brinda el acceso a la API  # noqa: E501

        :param account: The account of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._account = account

    @property
    def masked_account(self):
        """Gets the masked_account of this AuthorizedUsers.  # noqa: E501

        El contrato enmascarado al cual se le brinda el acceso a la API  # noqa: E501

        :return: The masked_account of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._masked_account

    @masked_account.setter
    def masked_account(self, masked_account):
        """Sets the masked_account of this AuthorizedUsers.

        El contrato enmascarado al cual se le brinda el acceso a la API  # noqa: E501

        :param masked_account: The masked_account of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._masked_account = masked_account

    @property
    def masked_name(self):
        """Gets the masked_name of this AuthorizedUsers.  # noqa: E501

        El usuario enmascarado que se autorizó  # noqa: E501

        :return: The masked_name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._masked_name

    @masked_name.setter
    def masked_name(self, masked_name):
        """Sets the masked_name of this AuthorizedUsers.

        El usuario enmascarado que se autorizó  # noqa: E501

        :param masked_name: The masked_name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._masked_name = masked_name

    @property
    def masked_user_name(self):
        """Gets the masked_user_name of this AuthorizedUsers.  # noqa: E501

        El nombre enmascarado del usuario de acceso que se autorizó  # noqa: E501

        :return: The masked_user_name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._masked_user_name

    @masked_user_name.setter
    def masked_user_name(self, masked_user_name):
        """Sets the masked_user_name of this AuthorizedUsers.

        El nombre enmascarado del usuario de acceso que se autorizó  # noqa: E501

        :param masked_user_name: The masked_user_name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._masked_user_name = masked_user_name

    @property
    def name(self):
        """Gets the name of this AuthorizedUsers.  # noqa: E501

        El usuario que se autorizó  # noqa: E501

        :return: The name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AuthorizedUsers.

        El usuario que se autorizó  # noqa: E501

        :param name: The name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def user_name(self):
        """Gets the user_name of this AuthorizedUsers.  # noqa: E501

        El usuario de acceso que se autorizó  # noqa: E501

        :return: The user_name of this AuthorizedUsers.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this AuthorizedUsers.

        El usuario de acceso que se autorizó  # noqa: E501

        :param user_name: The user_name of this AuthorizedUsers.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuthorizedUsers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthorizedUsers):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.depositantes_api import DepositantesApi  # noqa: E501
from wire4_client.rest import ApiException


class TestDepositantesApi(unittest.TestCase):
    """DepositantesApi unit test stubs"""

    def setUp(self):
        self.api = api.depositantes_api.DepositantesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_depositants_using_get(self):
        """Test case for get_depositants_using_get

        Consulta de cuentas de depositantes  # noqa: E501
        """
        pass

    def test_register_depositants_using_post(self):
        """Test case for register_depositants_using_post

        Registra un nuevo depositante  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.contracts_details_api import ContractsDetailsApi  # noqa: E501
from wire4_client.rest import ApiException


class TestContractsDetailsApi(unittest.TestCase):
    """ContractsDetailsApi unit test stubs"""

    def setUp(self):
        self.api = api.contracts_details_api.ContractsDetailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_authorization(self):
        """Test case for create_authorization

        Devuelve la URL para autorización del usuario Monex  # noqa: E501
        """
        pass

    def test_obtain_authorized_users(self):
        """Test case for obtain_authorized_users

        Obtiene los usuarios autorizados  # noqa: E501
        """
        pass

    def test_obtain_authorized_users_by_contract(self):
        """Test case for obtain_authorized_users_by_contract

        Obtiene los usuarios autorizados por contrato  # noqa: E501
        """
        pass

    def test_obtain_contract_details(self):
        """Test case for obtain_contract_details

        Obtiene los detalles de la empresa del contrato  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.beneficiary_institution import BeneficiaryInstitution  # noqa: F401,E501
from wire4_client.models.institution import Institution  # noqa: F401,E501


class SpidBeneficiaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_limit': 'float',
        'bank': 'Institution',
        'beneficiary_account': 'str',
        'email': 'list[str]',
        'institution': 'BeneficiaryInstitution',
        'kind_of_relationship': 'str',
        'numeric_reference_spid': 'str',
        'payment_concept_spid': 'str',
        'register_date': 'datetime',
        'relationship': 'str',
        'rfc': 'str',
        'status': 'str'
    }

    attribute_map = {
        'amount_limit': 'amount_limit',
        'bank': 'bank',
        'beneficiary_account': 'beneficiary_account',
        'email': 'email',
        'institution': 'institution',
        'kind_of_relationship': 'kind_of_relationship',
        'numeric_reference_spid': 'numeric_reference_spid',
        'payment_concept_spid': 'payment_concept_spid',
        'register_date': 'register_date',
        'relationship': 'relationship',
        'rfc': 'rfc',
        'status': 'status'
    }

    def __init__(self, amount_limit=None, bank=None, beneficiary_account=None, email=None, institution=None, kind_of_relationship=None, numeric_reference_spid=None, payment_concept_spid=None, register_date=None, relationship=None, rfc=None, status=None):  # noqa: E501
        """SpidBeneficiaryResponse - a model defined in Swagger"""  # noqa: E501
        self._amount_limit = None
        self._bank = None
        self._beneficiary_account = None
        self._email = None
        self._institution = None
        self._kind_of_relationship = None
        self._numeric_reference_spid = None
        self._payment_concept_spid = None
        self._register_date = None
        self._relationship = None
        self._rfc = None
        self._status = None
        self.discriminator = None
        self.amount_limit = amount_limit
        if bank is not None:
            self.bank = bank
        self.beneficiary_account = beneficiary_account
        if email is not None:
            self.email = email
        self.institution = institution
        self.kind_of_relationship = kind_of_relationship
        if numeric_reference_spid is not None:
            self.numeric_reference_spid = numeric_reference_spid
        if payment_concept_spid is not None:
            self.payment_concept_spid = payment_concept_spid
        if register_date is not None:
            self.register_date = register_date
        self.relationship = relationship
        if rfc is not None:
            self.rfc = rfc
        if status is not None:
            self.status = status

    @property
    def amount_limit(self):
        """Gets the amount_limit of this SpidBeneficiaryResponse.  # noqa: E501

        Monto límite permitido para la cuenta. Ejemplo: 1000.00  # noqa: E501

        :return: The amount_limit of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._amount_limit

    @amount_limit.setter
    def amount_limit(self, amount_limit):
        """Sets the amount_limit of this SpidBeneficiaryResponse.

        Monto límite permitido para la cuenta. Ejemplo: 1000.00  # noqa: E501

        :param amount_limit: The amount_limit of this SpidBeneficiaryResponse.  # noqa: E501
        :type: float
        """
        if amount_limit is None:
            raise ValueError("Invalid value for `amount_limit`, must not be `None`")  # noqa: E501

        self._amount_limit = amount_limit

    @property
    def bank(self):
        """Gets the bank of this SpidBeneficiaryResponse.  # noqa: E501


        :return: The bank of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: Institution
        """
        return self._bank

    @bank.setter
    def bank(self, bank):
        """Sets the bank of this SpidBeneficiaryResponse.


        :param bank: The bank of this SpidBeneficiaryResponse.  # noqa: E501
        :type: Institution
        """

        self._bank = bank

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this SpidBeneficiaryResponse.  # noqa: E501

        Cuenta del beneficiario debe ser una cuenta CLABE. Ejemplo: 032180000118359719.  # noqa: E501

        :return: The beneficiary_account of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this SpidBeneficiaryResponse.

        Cuenta del beneficiario debe ser una cuenta CLABE. Ejemplo: 032180000118359719.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this SpidBeneficiaryResponse.  # noqa: E501
        :type: str
        """
        if beneficiary_account is None:
            raise ValueError("Invalid value for `beneficiary_account`, must not be `None`")  # noqa: E501

        self._beneficiary_account = beneficiary_account

    @property
    def email(self):
        """Gets the email of this SpidBeneficiaryResponse.  # noqa: E501

        Lista de correos electrónicos (emails), este dato es opcional.  # noqa: E501

        :return: The email of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this SpidBeneficiaryResponse.

        Lista de correos electrónicos (emails), este dato es opcional.  # noqa: E501

        :param email: The email of this SpidBeneficiaryResponse.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def institution(self):
        """Gets the institution of this SpidBeneficiaryResponse.  # noqa: E501


        :return: The institution of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: BeneficiaryInstitution
        """
        return self._institution

    @institution.setter
    def institution(self, institution):
        """Sets the institution of this SpidBeneficiaryResponse.


        :param institution: The institution of this SpidBeneficiaryResponse.  # noqa: E501
        :type: BeneficiaryInstitution
        """
        if institution is None:
            raise ValueError("Invalid value for `institution`, must not be `None`")  # noqa: E501

        self._institution = institution

    @property
    def kind_of_relationship(self):
        """Gets the kind_of_relationship of this SpidBeneficiaryResponse.  # noqa: E501

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\"> relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :return: The kind_of_relationship of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._kind_of_relationship

    @kind_of_relationship.setter
    def kind_of_relationship(self, kind_of_relationship):
        """Sets the kind_of_relationship of this SpidBeneficiaryResponse.

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\"> relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :param kind_of_relationship: The kind_of_relationship of this SpidBeneficiaryResponse.  # noqa: E501
        :type: str
        """
        if kind_of_relationship is None:
            raise ValueError("Invalid value for `kind_of_relationship`, must not be `None`")  # noqa: E501

        self._kind_of_relationship = kind_of_relationship

    @property
    def numeric_reference_spid(self):
        """Gets the numeric_reference_spid of this SpidBeneficiaryResponse.  # noqa: E501

        Referencia numérica.  # noqa: E501

        :return: The numeric_reference_spid of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._numeric_reference_spid

    @numeric_reference_spid.setter
    def numeric_reference_spid(self, numeric_reference_spid):
        """Sets the numeric_reference_spid of this SpidBeneficiaryResponse.

        Referencia numérica.  # noqa: E501

        :param numeric_reference_spid: The numeric_reference_spid of this SpidBeneficiaryResponse.  # noqa: E501
        :type: str
        """

        self._numeric_reference_spid = numeric_reference_spid

    @property
    def payment_concept_spid(self):
        """Gets the payment_concept_spid of this SpidBeneficiaryResponse.  # noqa: E501

        Concepto de pago.  # noqa: E501

        :return: The payment_concept_spid of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._payment_concept_spid

    @payment_concept_spid.setter
    def payment_concept_spid(self, payment_concept_spid):
        """Sets the payment_concept_spid of this SpidBeneficiaryResponse.

        Concepto de pago.  # noqa: E501

        :param payment_concept_spid: The payment_concept_spid of this SpidBeneficiaryResponse.  # noqa: E501
        :type: str
        """

        self._payment_concept_spid = payment_concept_spid

    @property
    def register_date(self):
        """Gets the register_date of this SpidBeneficiaryResponse.  # noqa: E501

        La fecha en la que se registro el beneficiario.  # noqa: E501

        :return: The register_date of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._register_date

    @register_date.setter
    def register_date(self, register_date):
        """Sets the register_date of this SpidBeneficiaryResponse.

        La fecha en la que se registro el beneficiario.  # noqa: E501

        :param register_date: The register_date of this SpidBeneficiaryResponse.  # noqa: E501
        :type: datetime
        """

        self._register_date = register_date

    @property
    def relationship(self):
        """Gets the relationship of this SpidBeneficiaryResponse.  # noqa: E501

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :return: The relationship of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._relationship

    @relationship.setter
    def relationship(self, relationship):
        """Sets the relationship of this SpidBeneficiaryResponse.

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :param relationship: The relationship of this SpidBeneficiaryResponse.  # noqa: E501
        :type: str
        """
        if relationship is None:
            raise ValueError("Invalid value for `relationship`, must not be `None`")  # noqa: E501

        self._relationship = relationship

    @property
    def rfc(self):
        """Gets the rfc of this SpidBeneficiaryResponse.  # noqa: E501

        Es el Registro federal de contribuyentes (RFC) de la persona o institución propietaria de la cuenta. <br/> <br/><b>Nota:</b> Se valida el formato de RFC.  # noqa: E501

        :return: The rfc of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this SpidBeneficiaryResponse.

        Es el Registro federal de contribuyentes (RFC) de la persona o institución propietaria de la cuenta. <br/> <br/><b>Nota:</b> Se valida el formato de RFC.  # noqa: E501

        :param rfc: The rfc of this SpidBeneficiaryResponse.  # noqa: E501
        :type: str
        """

        self._rfc = rfc

    @property
    def status(self):
        """Gets the status of this SpidBeneficiaryResponse.  # noqa: E501

        El estado en el que se encuentra el registo del beneficiario.<br><br> Los valores pueden ser: <b>\"RECEIVED\", \"DELETED\", \"REQUEST_ERROR_BY_MONEX\", \"REQUESTED_TO_MONEX\", \"NOTIFIED_BY_MONEX\", \"NOTIFIED_BY_SPEIOK\", \"NOTIFIED_WITH_ERROR_BY_SPEIOK\" y \"PENDING\"</b>  # noqa: E501

        :return: The status of this SpidBeneficiaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SpidBeneficiaryResponse.

        El estado en el que se encuentra el registo del beneficiario.<br><br> Los valores pueden ser: <b>\"RECEIVED\", \"DELETED\", \"REQUEST_ERROR_BY_MONEX\", \"REQUESTED_TO_MONEX\", \"NOTIFIED_BY_MONEX\", \"NOTIFIED_BY_SPEIOK\", \"NOTIFIED_WITH_ERROR_BY_SPEIOK\" y \"PENDING\"</b>  # noqa: E501

        :param status: The status of this SpidBeneficiaryResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SpidBeneficiaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpidBeneficiaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from wire4_client.api.autorizacin_de_depsitos_api import AutorizacinDeDepsitosApi
from wire4_client.api.comprobante_electrnico_de_pago__cep_api import ComprobanteElectrnicoDePagoCEPApi
from wire4_client.api.contacto_api import ContactoApi
from wire4_client.api.contracts_details_api import ContractsDetailsApi
from wire4_client.api.cuentas_de_beneficiarios_spei_api import CuentasDeBeneficiariosSPEIApi
from wire4_client.api.cuentas_de_beneficiarios_spid_api import CuentasDeBeneficiariosSPIDApi
from wire4_client.api.depositantes_api import DepositantesApi
from wire4_client.api.empresas_co_di_api import EmpresasCoDiApi
from wire4_client.api.facturas_api import FacturasApi
from wire4_client.api.instituciones_api import InstitucionesApi
from wire4_client.api.lmites_de_montos_api import LmitesDeMontosApi
from wire4_client.api.operaciones_co_di_api import OperacionesCoDiApi
from wire4_client.api.peticiones_de_pago_por_co_di_api import PeticionesDePagoPorCoDiApi
from wire4_client.api.puntos_de_venta_co_di_api import PuntosDeVentaCoDiApi
from wire4_client.api.saldo_api import SaldoApi
from wire4_client.api.suscripciones_api import SuscripcionesApi
from wire4_client.api.transferencias_spei_api import TransferenciasSPEIApi
from wire4_client.api.transferencias_spid_api import TransferenciasSPIDApi
from wire4_client.api.webhooks_api import WebhooksApi



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ContractDetailRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contract': 'str',
        'password': 'str',
        'token_code': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'contract': 'contract',
        'password': 'password',
        'token_code': 'token_code',
        'user_name': 'user_name'
    }

    def __init__(self, contract=None, password=None, token_code=None, user_name=None):  # noqa: E501
        """ContractDetailRequest - a model defined in Swagger"""  # noqa: E501
        self._contract = None
        self._password = None
        self._token_code = None
        self._user_name = None
        self.discriminator = None
        if contract is not None:
            self.contract = contract
        if password is not None:
            self.password = password
        if token_code is not None:
            self.token_code = token_code
        if user_name is not None:
            self.user_name = user_name

    @property
    def contract(self):
        """Gets the contract of this ContractDetailRequest.  # noqa: E501

        El contrato a consultar la información  # noqa: E501

        :return: The contract of this ContractDetailRequest.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this ContractDetailRequest.

        El contrato a consultar la información  # noqa: E501

        :param contract: The contract of this ContractDetailRequest.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def password(self):
        """Gets the password of this ContractDetailRequest.  # noqa: E501

        La contraseña del usuario  # noqa: E501

        :return: The password of this ContractDetailRequest.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this ContractDetailRequest.

        La contraseña del usuario  # noqa: E501

        :param password: The password of this ContractDetailRequest.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def token_code(self):
        """Gets the token_code of this ContractDetailRequest.  # noqa: E501

        La contraseña del usuario  # noqa: E501

        :return: The token_code of this ContractDetailRequest.  # noqa: E501
        :rtype: str
        """
        return self._token_code

    @token_code.setter
    def token_code(self, token_code):
        """Sets the token_code of this ContractDetailRequest.

        La contraseña del usuario  # noqa: E501

        :param token_code: The token_code of this ContractDetailRequest.  # noqa: E501
        :type: str
        """

        self._token_code = token_code

    @property
    def user_name(self):
        """Gets the user_name of this ContractDetailRequest.  # noqa: E501

        El nombre del usuario  # noqa: E501

        :return: The user_name of this ContractDetailRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this ContractDetailRequest.

        El nombre del usuario  # noqa: E501

        :param user_name: The user_name of this ContractDetailRequest.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContractDetailRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContractDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.beneficiary_institution import BeneficiaryInstitution  # noqa: F401,E501


class AccountSpid(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_limit': 'float',
        'bank_code_banxico': 'str',
        'beneficiary_account': 'str',
        'cancel_return_url': 'str',
        'email': 'list[str]',
        'institution': 'BeneficiaryInstitution',
        'kind_of_relationship': 'str',
        'numeric_reference': 'str',
        'payment_concept': 'str',
        'relationship': 'str',
        'return_url': 'str',
        'rfc': 'str'
    }

    attribute_map = {
        'amount_limit': 'amount_limit',
        'bank_code_banxico': 'bank_code_banxico',
        'beneficiary_account': 'beneficiary_account',
        'cancel_return_url': 'cancel_return_url',
        'email': 'email',
        'institution': 'institution',
        'kind_of_relationship': 'kind_of_relationship',
        'numeric_reference': 'numeric_reference',
        'payment_concept': 'payment_concept',
        'relationship': 'relationship',
        'return_url': 'return_url',
        'rfc': 'rfc'
    }

    def __init__(self, amount_limit=None, bank_code_banxico=None, beneficiary_account=None, cancel_return_url=None, email=None, institution=None, kind_of_relationship=None, numeric_reference=None, payment_concept=None, relationship=None, return_url=None, rfc=None):  # noqa: E501
        """AccountSpid - a model defined in Swagger"""  # noqa: E501
        self._amount_limit = None
        self._bank_code_banxico = None
        self._beneficiary_account = None
        self._cancel_return_url = None
        self._email = None
        self._institution = None
        self._kind_of_relationship = None
        self._numeric_reference = None
        self._payment_concept = None
        self._relationship = None
        self._return_url = None
        self._rfc = None
        self.discriminator = None
        self.amount_limit = amount_limit
        if bank_code_banxico is not None:
            self.bank_code_banxico = bank_code_banxico
        self.beneficiary_account = beneficiary_account
        if cancel_return_url is not None:
            self.cancel_return_url = cancel_return_url
        if email is not None:
            self.email = email
        self.institution = institution
        self.kind_of_relationship = kind_of_relationship
        if numeric_reference is not None:
            self.numeric_reference = numeric_reference
        if payment_concept is not None:
            self.payment_concept = payment_concept
        self.relationship = relationship
        if return_url is not None:
            self.return_url = return_url
        if rfc is not None:
            self.rfc = rfc

    @property
    def amount_limit(self):
        """Gets the amount_limit of this AccountSpid.  # noqa: E501

        Monto límite permitido para la cuenta. Ejemplo: 1000.00  # noqa: E501

        :return: The amount_limit of this AccountSpid.  # noqa: E501
        :rtype: float
        """
        return self._amount_limit

    @amount_limit.setter
    def amount_limit(self, amount_limit):
        """Sets the amount_limit of this AccountSpid.

        Monto límite permitido para la cuenta. Ejemplo: 1000.00  # noqa: E501

        :param amount_limit: The amount_limit of this AccountSpid.  # noqa: E501
        :type: float
        """
        if amount_limit is None:
            raise ValueError("Invalid value for `amount_limit`, must not be `None`")  # noqa: E501

        self._amount_limit = amount_limit

    @property
    def bank_code_banxico(self):
        """Gets the bank_code_banxico of this AccountSpid.  # noqa: E501

        Es el código banxico con una longitud de 5 dígitos, es requerido en caso de que la cuenta del beneficiario sea un número de celular.  # noqa: E501

        :return: The bank_code_banxico of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._bank_code_banxico

    @bank_code_banxico.setter
    def bank_code_banxico(self, bank_code_banxico):
        """Sets the bank_code_banxico of this AccountSpid.

        Es el código banxico con una longitud de 5 dígitos, es requerido en caso de que la cuenta del beneficiario sea un número de celular.  # noqa: E501

        :param bank_code_banxico: The bank_code_banxico of this AccountSpid.  # noqa: E501
        :type: str
        """

        self._bank_code_banxico = bank_code_banxico

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this AccountSpid.  # noqa: E501

        Cuenta del beneficiario debe ser una cuenta CLABE. Ejemplo: 032180000118359719.  # noqa: E501

        :return: The beneficiary_account of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this AccountSpid.

        Cuenta del beneficiario debe ser una cuenta CLABE. Ejemplo: 032180000118359719.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this AccountSpid.  # noqa: E501
        :type: str
        """
        if beneficiary_account is None:
            raise ValueError("Invalid value for `beneficiary_account`, must not be `None`")  # noqa: E501

        self._beneficiary_account = beneficiary_account

    @property
    def cancel_return_url(self):
        """Gets the cancel_return_url of this AccountSpid.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso de que el cliente cancele el registro. Se valida hasta 512 caracteres.  # noqa: E501

        :return: The cancel_return_url of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._cancel_return_url

    @cancel_return_url.setter
    def cancel_return_url(self, cancel_return_url):
        """Sets the cancel_return_url of this AccountSpid.

        Es la dirección URL a la que se redirigirá en caso de que el cliente cancele el registro. Se valida hasta 512 caracteres.  # noqa: E501

        :param cancel_return_url: The cancel_return_url of this AccountSpid.  # noqa: E501
        :type: str
        """

        self._cancel_return_url = cancel_return_url

    @property
    def email(self):
        """Gets the email of this AccountSpid.  # noqa: E501

        Lista de correos electrónicos (emails), este dato es opcional.  # noqa: E501

        :return: The email of this AccountSpid.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AccountSpid.

        Lista de correos electrónicos (emails), este dato es opcional.  # noqa: E501

        :param email: The email of this AccountSpid.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def institution(self):
        """Gets the institution of this AccountSpid.  # noqa: E501


        :return: The institution of this AccountSpid.  # noqa: E501
        :rtype: BeneficiaryInstitution
        """
        return self._institution

    @institution.setter
    def institution(self, institution):
        """Sets the institution of this AccountSpid.


        :param institution: The institution of this AccountSpid.  # noqa: E501
        :type: BeneficiaryInstitution
        """
        if institution is None:
            raise ValueError("Invalid value for `institution`, must not be `None`")  # noqa: E501

        self._institution = institution

    @property
    def kind_of_relationship(self):
        """Gets the kind_of_relationship of this AccountSpid.  # noqa: E501

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\"> relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :return: The kind_of_relationship of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._kind_of_relationship

    @kind_of_relationship.setter
    def kind_of_relationship(self, kind_of_relationship):
        """Sets the kind_of_relationship of this AccountSpid.

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\"> relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :param kind_of_relationship: The kind_of_relationship of this AccountSpid.  # noqa: E501
        :type: str
        """
        if kind_of_relationship is None:
            raise ValueError("Invalid value for `kind_of_relationship`, must not be `None`")  # noqa: E501

        self._kind_of_relationship = kind_of_relationship

    @property
    def numeric_reference(self):
        """Gets the numeric_reference of this AccountSpid.  # noqa: E501

        Es la referencia numérica.  # noqa: E501

        :return: The numeric_reference of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._numeric_reference

    @numeric_reference.setter
    def numeric_reference(self, numeric_reference):
        """Sets the numeric_reference of this AccountSpid.

        Es la referencia numérica.  # noqa: E501

        :param numeric_reference: The numeric_reference of this AccountSpid.  # noqa: E501
        :type: str
        """

        self._numeric_reference = numeric_reference

    @property
    def payment_concept(self):
        """Gets the payment_concept of this AccountSpid.  # noqa: E501

        Es el concepto de pago.  # noqa: E501

        :return: The payment_concept of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._payment_concept

    @payment_concept.setter
    def payment_concept(self, payment_concept):
        """Sets the payment_concept of this AccountSpid.

        Es el concepto de pago.  # noqa: E501

        :param payment_concept: The payment_concept of this AccountSpid.  # noqa: E501
        :type: str
        """

        self._payment_concept = payment_concept

    @property
    def relationship(self):
        """Gets the relationship of this AccountSpid.  # noqa: E501

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :return: The relationship of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._relationship

    @relationship.setter
    def relationship(self, relationship):
        """Sets the relationship of this AccountSpid.

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :param relationship: The relationship of this AccountSpid.  # noqa: E501
        :type: str
        """
        if relationship is None:
            raise ValueError("Invalid value for `relationship`, must not be `None`")  # noqa: E501

        self._relationship = relationship

    @property
    def return_url(self):
        """Gets the return_url of this AccountSpid.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso exitoso. Se valida hasta 512 caracteres.  # noqa: E501

        :return: The return_url of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._return_url

    @return_url.setter
    def return_url(self, return_url):
        """Sets the return_url of this AccountSpid.

        Es la dirección URL a la que se redirigirá en caso exitoso. Se valida hasta 512 caracteres.  # noqa: E501

        :param return_url: The return_url of this AccountSpid.  # noqa: E501
        :type: str
        """

        self._return_url = return_url

    @property
    def rfc(self):
        """Gets the rfc of this AccountSpid.  # noqa: E501

        Es el Registro federal de contribuyentes (RFC) de la persona o institución propietaria de la cuenta. <br/> <br/><b>Nota:</b> Se valida el formato de RFC.  # noqa: E501

        :return: The rfc of this AccountSpid.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this AccountSpid.

        Es el Registro federal de contribuyentes (RFC) de la persona o institución propietaria de la cuenta. <br/> <br/><b>Nota:</b> Se valida el formato de RFC.  # noqa: E501

        :param rfc: The rfc of this AccountSpid.  # noqa: E501
        :type: str
        """

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccountSpid, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountSpid):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from models.authorization_transaction_group import AuthorizationTransactionGroup  # noqa: E501
from wire4_client.rest import ApiException


class TestAuthorizationTransactionGroup(unittest.TestCase):
    """AuthorizationTransactionGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthorizationTransactionGroup(self):
        """Test AuthorizationTransactionGroup"""
        # FIXME: construct object with mandatory attributes with example values
        # model = wire4_client.models.authorization_transaction_group.AuthorizationTransactionGroup()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wire4_client.api_client import ApiClient


class TransferenciasSPIDApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_spid_classifications_using_get(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de clasificaciones para operaciones SPID®  # noqa: E501

        Obtiene las clasificaciones para operaciones con dólares (SPID®) de Monex.<br/><br/>Este recurso se debe invocar previo al realizar una operación SPID.<br/><br/>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_spid_classifications_using_get(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: SpidClassificationsResponseDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_spid_classifications_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.get_spid_classifications_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
            return data

    def get_spid_classifications_using_get_with_http_info(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de clasificaciones para operaciones SPID®  # noqa: E501

        Obtiene las clasificaciones para operaciones con dólares (SPID®) de Monex.<br/><br/>Este recurso se debe invocar previo al realizar una operación SPID.<br/><br/>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_spid_classifications_using_get_with_http_info(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: SpidClassificationsResponseDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_spid_classifications_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_spid_classifications_using_get`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `get_spid_classifications_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/spid/classifications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SpidClassificationsResponseDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_outgoing_spid_transaction_using_post(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Registro de transferencias SPID®  # noqa: E501

        Registra un conjunto de transferencias a realizar en la cuenta del cliente Monex relacionada a la suscripción. En la respuesta se proporcionará una dirección URL que lo llevará al centro de autorización para que las transferencias sean confirmadas (autorizadas) por el cliente para que se efectúen, para ello debe ingresar la llave electrónica (Token).<br> Nota: Debe considerar que el concepto de cada una de las transacciones solo debe contener caracteres alfanuméricos por lo que en caso de que se reciban caracteres como ñ o acentos serán sustituidos por n o en su caso por la letra sin acento. Los caracteres no alfanuméricos como pueden ser caracteres especiales serán eliminados.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_outgoing_spid_transaction_using_post(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TransactionOutgoingSpid body: Información de las transferencias SPID de salida (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_outgoing_spid_transaction_using_post_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.register_outgoing_spid_transaction_using_post_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
            return data

    def register_outgoing_spid_transaction_using_post_with_http_info(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Registro de transferencias SPID®  # noqa: E501

        Registra un conjunto de transferencias a realizar en la cuenta del cliente Monex relacionada a la suscripción. En la respuesta se proporcionará una dirección URL que lo llevará al centro de autorización para que las transferencias sean confirmadas (autorizadas) por el cliente para que se efectúen, para ello debe ingresar la llave electrónica (Token).<br> Nota: Debe considerar que el concepto de cada una de las transacciones solo debe contener caracteres alfanuméricos por lo que en caso de que se reciban caracteres como ñ o acentos serán sustituidos por n o en su caso por la letra sin acento. Los caracteres no alfanuméricos como pueden ser caracteres especiales serán eliminados.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_outgoing_spid_transaction_using_post_with_http_info(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TransactionOutgoingSpid body: Información de las transferencias SPID de salida (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_outgoing_spid_transaction_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_outgoing_spid_transaction_using_post`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `register_outgoing_spid_transaction_using_post`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `register_outgoing_spid_transaction_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/transactions/outcoming/spid', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenRequiredResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.web_hook_deposit_authorization_request import WebHookDepositAuthorizationRequest  # noqa: F401,E501


class DepositAuthorizationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'webhook': 'WebHookDepositAuthorizationRequest',
        'wh_uuid': 'str'
    }

    attribute_map = {
        'enabled': 'enabled',
        'webhook': 'webhook',
        'wh_uuid': 'wh_uuid'
    }

    def __init__(self, enabled=None, webhook=None, wh_uuid=None):  # noqa: E501
        """DepositAuthorizationRequest - a model defined in Swagger"""  # noqa: E501
        self._enabled = None
        self._webhook = None
        self._wh_uuid = None
        self.discriminator = None
        if enabled is not None:
            self.enabled = enabled
        if webhook is not None:
            self.webhook = webhook
        if wh_uuid is not None:
            self.wh_uuid = wh_uuid

    @property
    def enabled(self):
        """Gets the enabled of this DepositAuthorizationRequest.  # noqa: E501

        Indica sí se aplica la autorización de depósitos.  # noqa: E501

        :return: The enabled of this DepositAuthorizationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DepositAuthorizationRequest.

        Indica sí se aplica la autorización de depósitos.  # noqa: E501

        :param enabled: The enabled of this DepositAuthorizationRequest.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def webhook(self):
        """Gets the webhook of this DepositAuthorizationRequest.  # noqa: E501


        :return: The webhook of this DepositAuthorizationRequest.  # noqa: E501
        :rtype: WebHookDepositAuthorizationRequest
        """
        return self._webhook

    @webhook.setter
    def webhook(self, webhook):
        """Sets the webhook of this DepositAuthorizationRequest.


        :param webhook: The webhook of this DepositAuthorizationRequest.  # noqa: E501
        :type: WebHookDepositAuthorizationRequest
        """

        self._webhook = webhook

    @property
    def wh_uuid(self):
        """Gets the wh_uuid of this DepositAuthorizationRequest.  # noqa: E501

        Identificador del webhook.  # noqa: E501

        :return: The wh_uuid of this DepositAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._wh_uuid

    @wh_uuid.setter
    def wh_uuid(self, wh_uuid):
        """Sets the wh_uuid of this DepositAuthorizationRequest.

        Identificador del webhook.  # noqa: E501

        :param wh_uuid: The wh_uuid of this DepositAuthorizationRequest.  # noqa: E501
        :type: str
        """

        self._wh_uuid = wh_uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DepositAuthorizationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DepositAuthorizationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.puntos_de_venta_co_di_api import PuntosDeVentaCoDiApi  # noqa: E501
from wire4_client.rest import ApiException


class TestPuntosDeVentaCoDiApi(unittest.TestCase):
    """PuntosDeVentaCoDiApi unit test stubs"""

    def setUp(self):
        self.api = api.puntos_de_venta_co_di_api.PuntosDeVentaCoDiApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_sales_point(self):
        """Test case for create_sales_point

        Registro de punto de venta.  # noqa: E501
        """
        pass

    def test_obtain_sale_points(self):
        """Test case for obtain_sale_points

        Consulta de puntos de venta  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wire4_client.api_client import ApiClient


class CuentasDeBeneficiariosSPEIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def authorize_accounts_pending_put(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Solicitud para agrupar cuentas de beneficiarios SPEI/SPID en estado pendiente.  # noqa: E501

        Solicta la agrupación de las cuentas de beneficiarios en estado pendiente para que sean autorizadas,  para ello se crea un conjunto de éstas que puede incluir tanto de SPEI como de SPID. Además se debe indicar las urls de redirección en caso de error y éxito  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authorize_accounts_pending_put(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlsRedirect body: Información de la cuenta del beneficiario (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: AuthorizedBeneficiariesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.authorize_accounts_pending_put_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.authorize_accounts_pending_put_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
            return data

    def authorize_accounts_pending_put_with_http_info(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Solicitud para agrupar cuentas de beneficiarios SPEI/SPID en estado pendiente.  # noqa: E501

        Solicta la agrupación de las cuentas de beneficiarios en estado pendiente para que sean autorizadas,  para ello se crea un conjunto de éstas que puede incluir tanto de SPEI como de SPID. Además se debe indicar las urls de redirección en caso de error y éxito  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authorize_accounts_pending_put_with_http_info(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlsRedirect body: Información de la cuenta del beneficiario (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: AuthorizedBeneficiariesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method authorize_accounts_pending_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `authorize_accounts_pending_put`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `authorize_accounts_pending_put`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `authorize_accounts_pending_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/pending', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuthorizedBeneficiariesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_account_using_delete(self, authorization, account, subscription, **kwargs):  # noqa: E501
        """Elimina la cuenta del beneficiario  # noqa: E501

        Elimina la cuenta de beneficiario proporcionada relacionada al contrato perteneciente a la suscripción. La cuenta a borrar debe ser una que opere con SPEI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_account_using_delete(authorization, account, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str account: Es la cuenta del beneficiario que será eliminada. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_account_using_delete_with_http_info(authorization, account, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_account_using_delete_with_http_info(authorization, account, subscription, **kwargs)  # noqa: E501
            return data

    def delete_account_using_delete_with_http_info(self, authorization, account, subscription, **kwargs):  # noqa: E501
        """Elimina la cuenta del beneficiario  # noqa: E501

        Elimina la cuenta de beneficiario proporcionada relacionada al contrato perteneciente a la suscripción. La cuenta a borrar debe ser una que opere con SPEI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_account_using_delete_with_http_info(authorization, account, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str account: Es la cuenta del beneficiario que será eliminada. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'account', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_account_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `delete_account_using_delete`")  # noqa: E501
        # verify the required parameter 'account' is set
        if ('account' not in params or
                params['account'] is None):
            raise ValueError("Missing the required parameter `account` when calling `delete_account_using_delete`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `delete_account_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account' in params:
            path_params['account'] = params['account']  # noqa: E501
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/spei/{account}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_relationships_monex_using_get(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de relaciones  # noqa: E501

        Obtiene las posibles relaciones existentes para registrar beneficiarios en Monex. Se debe invocar este recurso antes de pre-registrar una cuenta de beneficiario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_relationships_monex_using_get(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: RelationshipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_relationships_monex_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.get_available_relationships_monex_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
            return data

    def get_available_relationships_monex_using_get_with_http_info(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de relaciones  # noqa: E501

        Obtiene las posibles relaciones existentes para registrar beneficiarios en Monex. Se debe invocar este recurso antes de pre-registrar una cuenta de beneficiario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_relationships_monex_using_get_with_http_info(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: RelationshipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_relationships_monex_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_available_relationships_monex_using_get`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `get_available_relationships_monex_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/relationships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationshipsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_beneficiaries_by_request_id(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Consulta los beneficiarios por el identificador de la petición de registro  # noqa: E501

        Obtiene los beneficiarios enviados para registro en una petición al contrato relacionado con la suscripción, Los beneficiarios son los que actualmente se encuentran registrados en banca Monex, que pertenezcan a la petición que se solicita.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beneficiaries_by_request_id(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: El identificador de la petición del registro de beneficiarios a esta API. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: BeneficiariesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_beneficiaries_by_request_id_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.get_beneficiaries_by_request_id_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
            return data

    def get_beneficiaries_by_request_id_with_http_info(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Consulta los beneficiarios por el identificador de la petición de registro  # noqa: E501

        Obtiene los beneficiarios enviados para registro en una petición al contrato relacionado con la suscripción, Los beneficiarios son los que actualmente se encuentran registrados en banca Monex, que pertenezcan a la petición que se solicita.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beneficiaries_by_request_id_with_http_info(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: El identificador de la petición del registro de beneficiarios a esta API. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: BeneficiariesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'request_id', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beneficiaries_by_request_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_beneficiaries_by_request_id`")  # noqa: E501
        # verify the required parameter 'request_id' is set
        if ('request_id' not in params or
                params['request_id'] is None):
            raise ValueError("Missing the required parameter `request_id` when calling `get_beneficiaries_by_request_id`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `get_beneficiaries_by_request_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'request_id' in params:
            path_params['requestId'] = params['request_id']  # noqa: E501
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/spei/{requestId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BeneficiariesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_beneficiaries_for_account_using_get(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta los beneficiarios registrados  # noqa: E501

        Obtiene los beneficiarios registrados al contrato relacionado con la suscripción, Los beneficiarios son los que actualmente se encuentran registrados en banca Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beneficiaries_for_account_using_get(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str account: Es la cuenta del beneficiario, podría ser teléfono celular (es de 10 dígitos), Tarjeta de débito (TDD, es de 16 dígitos) o cuenta CLABE (es de 18 dígitos). <br/><br/>Por ejemplo Teléfono celular: 5525072600, TDD: 4323 1234 5678 9123, CLABE: 032180000118359719.
        :param str beneficiary_bank: Es la clave del banco beneficiario. Se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>
        :param str beneficiary_name: Es el nombre del beneficiario.
        :param str end_date: Es la fecha de inicio del perido a filtrar en formato dd-mm-yyyy.
        :param str init_date: Es la fºecha de inicio del perido a filtrar en formato dd-mm-yyyy.
        :param str rfc: Es el Registro Federal de Controbuyentes (RFC) del beneficiario.
        :param str status: Es el estado (estatus) de la cuenta. Los valores pueden ser <b>PENDING</b> y <b>REGISTERED</b>.
        :return: BeneficiariesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_beneficiaries_for_account_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.get_beneficiaries_for_account_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
            return data

    def get_beneficiaries_for_account_using_get_with_http_info(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta los beneficiarios registrados  # noqa: E501

        Obtiene los beneficiarios registrados al contrato relacionado con la suscripción, Los beneficiarios son los que actualmente se encuentran registrados en banca Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beneficiaries_for_account_using_get_with_http_info(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str account: Es la cuenta del beneficiario, podría ser teléfono celular (es de 10 dígitos), Tarjeta de débito (TDD, es de 16 dígitos) o cuenta CLABE (es de 18 dígitos). <br/><br/>Por ejemplo Teléfono celular: 5525072600, TDD: 4323 1234 5678 9123, CLABE: 032180000118359719.
        :param str beneficiary_bank: Es la clave del banco beneficiario. Se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>
        :param str beneficiary_name: Es el nombre del beneficiario.
        :param str end_date: Es la fecha de inicio del perido a filtrar en formato dd-mm-yyyy.
        :param str init_date: Es la fºecha de inicio del perido a filtrar en formato dd-mm-yyyy.
        :param str rfc: Es el Registro Federal de Controbuyentes (RFC) del beneficiario.
        :param str status: Es el estado (estatus) de la cuenta. Los valores pueden ser <b>PENDING</b> y <b>REGISTERED</b>.
        :return: BeneficiariesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'subscription', 'account', 'beneficiary_bank', 'beneficiary_name', 'end_date', 'init_date', 'rfc', 'status']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beneficiaries_for_account_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_beneficiaries_for_account_using_get`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `get_beneficiaries_for_account_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []
        if 'account' in params:
            query_params.append(('account', params['account']))  # noqa: E501
        if 'beneficiary_bank' in params:
            query_params.append(('beneficiary_bank', params['beneficiary_bank']))  # noqa: E501
        if 'beneficiary_name' in params:
            query_params.append(('beneficiary_name', params['beneficiary_name']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'init_date' in params:
            query_params.append(('init_date', params['init_date']))  # noqa: E501
        if 'rfc' in params:
            query_params.append(('rfc', params['rfc']))  # noqa: E501
        if 'status' in params:
            query_params.append(('status', params['status']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/spei', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BeneficiariesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pre_register_accounts_using_post(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Pre-registro de cuentas de beneficiarios SPEI®.  # noqa: E501

        Pre-registra una o más cuentas de beneficiario en la plataforma de Wire4, ésta le proporcionará una URL donde lo llevará al centro de autorización para que el cuentahabiente Monex ingrese su llave digital para confirmar el alta de las cuentas de beneficiarios.<br/> Los posibles valores de <em>relationship</em> y <em>kind_of_relationship</em> se deben  obtener de <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">/subscriptions/{subscription}/beneficiaries/relationships.</a><br/><br/>La confirmación de registro en Monex se realizará a través de una notificación a los webhooks registrados con el evento de tipo <a href=\"#section/Eventos/Tipos-de-Eventos\">ACCOUNT.CREATED.</a>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pre_register_accounts_using_post(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccountRequest body: Información de la cuenta del beneficiario (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.pre_register_accounts_using_post_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.pre_register_accounts_using_post_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
            return data

    def pre_register_accounts_using_post_with_http_info(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Pre-registro de cuentas de beneficiarios SPEI®.  # noqa: E501

        Pre-registra una o más cuentas de beneficiario en la plataforma de Wire4, ésta le proporcionará una URL donde lo llevará al centro de autorización para que el cuentahabiente Monex ingrese su llave digital para confirmar el alta de las cuentas de beneficiarios.<br/> Los posibles valores de <em>relationship</em> y <em>kind_of_relationship</em> se deben  obtener de <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">/subscriptions/{subscription}/beneficiaries/relationships.</a><br/><br/>La confirmación de registro en Monex se realizará a través de una notificación a los webhooks registrados con el evento de tipo <a href=\"#section/Eventos/Tipos-de-Eventos\">ACCOUNT.CREATED.</a>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pre_register_accounts_using_post_with_http_info(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccountRequest body: Información de la cuenta del beneficiario (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pre_register_accounts_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `pre_register_accounts_using_post`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `pre_register_accounts_using_post`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `pre_register_accounts_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/spei', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenRequiredResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_beneficiaries_pending_using_delete(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Eliminación de beneficiarios SPEI® sin confirmar  # noqa: E501

        Elimina uno o más beneficiarios que se encuentran en estado pendiente de confirmar (autorizar) de la cuenta del cliente Monex relacionada a la suscripción.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_beneficiaries_pending_using_delete(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: Es el identificador con el que se dió de alta a los beneficiarios (viene en el cuerpo de la respuesta del <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">pre-registro de beneficiarios</a>), los registros bajo éste campo van a ser eliminados. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_beneficiaries_pending_using_delete_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_beneficiaries_pending_using_delete_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
            return data

    def remove_beneficiaries_pending_using_delete_with_http_info(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Eliminación de beneficiarios SPEI® sin confirmar  # noqa: E501

        Elimina uno o más beneficiarios que se encuentran en estado pendiente de confirmar (autorizar) de la cuenta del cliente Monex relacionada a la suscripción.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_beneficiaries_pending_using_delete_with_http_info(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: Es el identificador con el que se dió de alta a los beneficiarios (viene en el cuerpo de la respuesta del <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">pre-registro de beneficiarios</a>), los registros bajo éste campo van a ser eliminados. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'request_id', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_beneficiaries_pending_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `remove_beneficiaries_pending_using_delete`")  # noqa: E501
        # verify the required parameter 'request_id' is set
        if ('request_id' not in params or
                params['request_id'] is None):
            raise ValueError("Missing the required parameter `request_id` when calling `remove_beneficiaries_pending_using_delete`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `remove_beneficiaries_pending_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'request_id' in params:
            path_params['requestId'] = params['request_id']  # noqa: E501
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/spei/request/{requestId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_amount_limit_account_using_put(self, body, authorization, account, subscription, **kwargs):  # noqa: E501
        """Solicitud para actualizar el monto límite de una cuenta  # noqa: E501

        Se crea una solicitud para actualizar el monto límite a la cuenta de beneficiario proporcionada y relacionada al contrato perteneciente a la subscripción. Una vez enviada la solicitud se retornará una URl que lo llevará al centro de autorización para que el cuentahabiente Monex ingrese su llave digital para confirmar la actualización del monto límite.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_amount_limit_account_using_put(body, authorization, account, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AmountRequest body: Información de la cuenta y el monto límite a actualizar. (required)
        :param str authorization: Header para token (required)
        :param str account: Es la cuenta que va a ser actualizada. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_amount_limit_account_using_put_with_http_info(body, authorization, account, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.update_amount_limit_account_using_put_with_http_info(body, authorization, account, subscription, **kwargs)  # noqa: E501
            return data

    def update_amount_limit_account_using_put_with_http_info(self, body, authorization, account, subscription, **kwargs):  # noqa: E501
        """Solicitud para actualizar el monto límite de una cuenta  # noqa: E501

        Se crea una solicitud para actualizar el monto límite a la cuenta de beneficiario proporcionada y relacionada al contrato perteneciente a la subscripción. Una vez enviada la solicitud se retornará una URl que lo llevará al centro de autorización para que el cuentahabiente Monex ingrese su llave digital para confirmar la actualización del monto límite.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_amount_limit_account_using_put_with_http_info(body, authorization, account, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AmountRequest body: Información de la cuenta y el monto límite a actualizar. (required)
        :param str authorization: Header para token (required)
        :param str account: Es la cuenta que va a ser actualizada. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'account', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_amount_limit_account_using_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_amount_limit_account_using_put`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `update_amount_limit_account_using_put`")  # noqa: E501
        # verify the required parameter 'account' is set
        if ('account' not in params or
                params['account'] is None):
            raise ValueError("Missing the required parameter `account` when calling `update_amount_limit_account_using_put`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `update_amount_limit_account_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account' in params:
            path_params['account'] = params['account']  # noqa: E501
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/beneficiaries/spei/{account}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenRequiredResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CepResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_beneficiary': 'str',
        'account_sender': 'str',
        'amount': 'float',
        'available': 'bool',
        'beneficiary_bank_key': 'str',
        'beneficiary_name': 'str',
        'beneficiary_rfc': 'str',
        'cadena_original': 'str',
        'capture_date': 'datetime',
        'certificate_serial_number': 'str',
        'clave_rastreo': 'str',
        'description': 'str',
        'iva': 'float',
        'operation_date': 'datetime',
        'operation_date_cep': 'datetime',
        'reference': 'str',
        'sender_bank_key': 'str',
        'sender_name': 'str',
        'sender_rfc': 'str',
        'signature': 'str',
        'url_zip': 'str'
    }

    attribute_map = {
        'account_beneficiary': 'account_beneficiary',
        'account_sender': 'account_sender',
        'amount': 'amount',
        'available': 'available',
        'beneficiary_bank_key': 'beneficiary_bank_key',
        'beneficiary_name': 'beneficiary_name',
        'beneficiary_rfc': 'beneficiary_rfc',
        'cadena_original': 'cadena_original',
        'capture_date': 'capture_date',
        'certificate_serial_number': 'certificate_serial_number',
        'clave_rastreo': 'clave_rastreo',
        'description': 'description',
        'iva': 'iva',
        'operation_date': 'operation_date',
        'operation_date_cep': 'operation_date_cep',
        'reference': 'reference',
        'sender_bank_key': 'sender_bank_key',
        'sender_name': 'sender_name',
        'sender_rfc': 'sender_rfc',
        'signature': 'signature',
        'url_zip': 'url_zip'
    }

    def __init__(self, account_beneficiary=None, account_sender=None, amount=None, available=None, beneficiary_bank_key=None, beneficiary_name=None, beneficiary_rfc=None, cadena_original=None, capture_date=None, certificate_serial_number=None, clave_rastreo=None, description=None, iva=None, operation_date=None, operation_date_cep=None, reference=None, sender_bank_key=None, sender_name=None, sender_rfc=None, signature=None, url_zip=None):  # noqa: E501
        """CepResponse - a model defined in Swagger"""  # noqa: E501
        self._account_beneficiary = None
        self._account_sender = None
        self._amount = None
        self._available = None
        self._beneficiary_bank_key = None
        self._beneficiary_name = None
        self._beneficiary_rfc = None
        self._cadena_original = None
        self._capture_date = None
        self._certificate_serial_number = None
        self._clave_rastreo = None
        self._description = None
        self._iva = None
        self._operation_date = None
        self._operation_date_cep = None
        self._reference = None
        self._sender_bank_key = None
        self._sender_name = None
        self._sender_rfc = None
        self._signature = None
        self._url_zip = None
        self.discriminator = None
        if account_beneficiary is not None:
            self.account_beneficiary = account_beneficiary
        if account_sender is not None:
            self.account_sender = account_sender
        if amount is not None:
            self.amount = amount
        if available is not None:
            self.available = available
        if beneficiary_bank_key is not None:
            self.beneficiary_bank_key = beneficiary_bank_key
        if beneficiary_name is not None:
            self.beneficiary_name = beneficiary_name
        if beneficiary_rfc is not None:
            self.beneficiary_rfc = beneficiary_rfc
        if cadena_original is not None:
            self.cadena_original = cadena_original
        if capture_date is not None:
            self.capture_date = capture_date
        if certificate_serial_number is not None:
            self.certificate_serial_number = certificate_serial_number
        if clave_rastreo is not None:
            self.clave_rastreo = clave_rastreo
        if description is not None:
            self.description = description
        if iva is not None:
            self.iva = iva
        if operation_date is not None:
            self.operation_date = operation_date
        if operation_date_cep is not None:
            self.operation_date_cep = operation_date_cep
        if reference is not None:
            self.reference = reference
        if sender_bank_key is not None:
            self.sender_bank_key = sender_bank_key
        if sender_name is not None:
            self.sender_name = sender_name
        if sender_rfc is not None:
            self.sender_rfc = sender_rfc
        if signature is not None:
            self.signature = signature
        if url_zip is not None:
            self.url_zip = url_zip

    @property
    def account_beneficiary(self):
        """Gets the account_beneficiary of this CepResponse.  # noqa: E501

        Es la cuenta del beneficiario.  # noqa: E501

        :return: The account_beneficiary of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._account_beneficiary

    @account_beneficiary.setter
    def account_beneficiary(self, account_beneficiary):
        """Sets the account_beneficiary of this CepResponse.

        Es la cuenta del beneficiario.  # noqa: E501

        :param account_beneficiary: The account_beneficiary of this CepResponse.  # noqa: E501
        :type: str
        """

        self._account_beneficiary = account_beneficiary

    @property
    def account_sender(self):
        """Gets the account_sender of this CepResponse.  # noqa: E501

        Es la cuenta del ordenante.  # noqa: E501

        :return: The account_sender of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._account_sender

    @account_sender.setter
    def account_sender(self, account_sender):
        """Sets the account_sender of this CepResponse.

        Es la cuenta del ordenante.  # noqa: E501

        :param account_sender: The account_sender of this CepResponse.  # noqa: E501
        :type: str
        """

        self._account_sender = account_sender

    @property
    def amount(self):
        """Gets the amount of this CepResponse.  # noqa: E501

        Es el monto de la transferencia.  # noqa: E501

        :return: The amount of this CepResponse.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CepResponse.

        Es el monto de la transferencia.  # noqa: E501

        :param amount: The amount of this CepResponse.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def available(self):
        """Gets the available of this CepResponse.  # noqa: E501

        Indica si el CEP se encuentra disponible o no.  # noqa: E501

        :return: The available of this CepResponse.  # noqa: E501
        :rtype: bool
        """
        return self._available

    @available.setter
    def available(self, available):
        """Sets the available of this CepResponse.

        Indica si el CEP se encuentra disponible o no.  # noqa: E501

        :param available: The available of this CepResponse.  # noqa: E501
        :type: bool
        """

        self._available = available

    @property
    def beneficiary_bank_key(self):
        """Gets the beneficiary_bank_key of this CepResponse.  # noqa: E501

        Es la clave del banco beneficiario el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :return: The beneficiary_bank_key of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_bank_key

    @beneficiary_bank_key.setter
    def beneficiary_bank_key(self, beneficiary_bank_key):
        """Sets the beneficiary_bank_key of this CepResponse.

        Es la clave del banco beneficiario el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :param beneficiary_bank_key: The beneficiary_bank_key of this CepResponse.  # noqa: E501
        :type: str
        """

        self._beneficiary_bank_key = beneficiary_bank_key

    @property
    def beneficiary_name(self):
        """Gets the beneficiary_name of this CepResponse.  # noqa: E501

        Nombre del beneficiario.  # noqa: E501

        :return: The beneficiary_name of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_name

    @beneficiary_name.setter
    def beneficiary_name(self, beneficiary_name):
        """Sets the beneficiary_name of this CepResponse.

        Nombre del beneficiario.  # noqa: E501

        :param beneficiary_name: The beneficiary_name of this CepResponse.  # noqa: E501
        :type: str
        """

        self._beneficiary_name = beneficiary_name

    @property
    def beneficiary_rfc(self):
        """Gets the beneficiary_rfc of this CepResponse.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) del beneficiario.  # noqa: E501

        :return: The beneficiary_rfc of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_rfc

    @beneficiary_rfc.setter
    def beneficiary_rfc(self, beneficiary_rfc):
        """Sets the beneficiary_rfc of this CepResponse.

        Es el Registro Federal de Contribuyentes (RFC) del beneficiario.  # noqa: E501

        :param beneficiary_rfc: The beneficiary_rfc of this CepResponse.  # noqa: E501
        :type: str
        """

        self._beneficiary_rfc = beneficiary_rfc

    @property
    def cadena_original(self):
        """Gets the cadena_original of this CepResponse.  # noqa: E501

        Cadena original del CEP.  # noqa: E501

        :return: The cadena_original of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._cadena_original

    @cadena_original.setter
    def cadena_original(self, cadena_original):
        """Sets the cadena_original of this CepResponse.

        Cadena original del CEP.  # noqa: E501

        :param cadena_original: The cadena_original of this CepResponse.  # noqa: E501
        :type: str
        """

        self._cadena_original = cadena_original

    @property
    def capture_date(self):
        """Gets the capture_date of this CepResponse.  # noqa: E501

        Es la fecha de captura de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The capture_date of this CepResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._capture_date

    @capture_date.setter
    def capture_date(self, capture_date):
        """Sets the capture_date of this CepResponse.

        Es la fecha de captura de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param capture_date: The capture_date of this CepResponse.  # noqa: E501
        :type: datetime
        """

        self._capture_date = capture_date

    @property
    def certificate_serial_number(self):
        """Gets the certificate_serial_number of this CepResponse.  # noqa: E501

        Número de serie del certificado.  # noqa: E501

        :return: The certificate_serial_number of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._certificate_serial_number

    @certificate_serial_number.setter
    def certificate_serial_number(self, certificate_serial_number):
        """Sets the certificate_serial_number of this CepResponse.

        Número de serie del certificado.  # noqa: E501

        :param certificate_serial_number: The certificate_serial_number of this CepResponse.  # noqa: E501
        :type: str
        """

        self._certificate_serial_number = certificate_serial_number

    @property
    def clave_rastreo(self):
        """Gets the clave_rastreo of this CepResponse.  # noqa: E501

        Es la clave de rastreo.  # noqa: E501

        :return: The clave_rastreo of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._clave_rastreo

    @clave_rastreo.setter
    def clave_rastreo(self, clave_rastreo):
        """Sets the clave_rastreo of this CepResponse.

        Es la clave de rastreo.  # noqa: E501

        :param clave_rastreo: The clave_rastreo of this CepResponse.  # noqa: E501
        :type: str
        """

        self._clave_rastreo = clave_rastreo

    @property
    def description(self):
        """Gets the description of this CepResponse.  # noqa: E501

        Es la descripción de la transferencia.  # noqa: E501

        :return: The description of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CepResponse.

        Es la descripción de la transferencia.  # noqa: E501

        :param description: The description of this CepResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def iva(self):
        """Gets the iva of this CepResponse.  # noqa: E501

        IVA de la transferencia.  # noqa: E501

        :return: The iva of this CepResponse.  # noqa: E501
        :rtype: float
        """
        return self._iva

    @iva.setter
    def iva(self, iva):
        """Sets the iva of this CepResponse.

        IVA de la transferencia.  # noqa: E501

        :param iva: The iva of this CepResponse.  # noqa: E501
        :type: float
        """

        self._iva = iva

    @property
    def operation_date(self):
        """Gets the operation_date of this CepResponse.  # noqa: E501

        Es la fecha de operación de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The operation_date of this CepResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this CepResponse.

        Es la fecha de operación de la transferencia. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param operation_date: The operation_date of this CepResponse.  # noqa: E501
        :type: datetime
        """

        self._operation_date = operation_date

    @property
    def operation_date_cep(self):
        """Gets the operation_date_cep of this CepResponse.  # noqa: E501

        Es la fecha de abono registrada en el CEP.  Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The operation_date_cep of this CepResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date_cep

    @operation_date_cep.setter
    def operation_date_cep(self, operation_date_cep):
        """Sets the operation_date_cep of this CepResponse.

        Es la fecha de abono registrada en el CEP.  Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param operation_date_cep: The operation_date_cep of this CepResponse.  # noqa: E501
        :type: datetime
        """

        self._operation_date_cep = operation_date_cep

    @property
    def reference(self):
        """Gets the reference of this CepResponse.  # noqa: E501

        Es la referencia numérica de la transferencia.  # noqa: E501

        :return: The reference of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this CepResponse.

        Es la referencia numérica de la transferencia.  # noqa: E501

        :param reference: The reference of this CepResponse.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def sender_bank_key(self):
        """Gets the sender_bank_key of this CepResponse.  # noqa: E501

        Es la clave del banco emisor el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :return: The sender_bank_key of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._sender_bank_key

    @sender_bank_key.setter
    def sender_bank_key(self, sender_bank_key):
        """Sets the sender_bank_key of this CepResponse.

        Es la clave del banco emisor el cual se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :param sender_bank_key: The sender_bank_key of this CepResponse.  # noqa: E501
        :type: str
        """

        self._sender_bank_key = sender_bank_key

    @property
    def sender_name(self):
        """Gets the sender_name of this CepResponse.  # noqa: E501

        Es el nombre del emisor.  # noqa: E501

        :return: The sender_name of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._sender_name

    @sender_name.setter
    def sender_name(self, sender_name):
        """Sets the sender_name of this CepResponse.

        Es el nombre del emisor.  # noqa: E501

        :param sender_name: The sender_name of this CepResponse.  # noqa: E501
        :type: str
        """

        self._sender_name = sender_name

    @property
    def sender_rfc(self):
        """Gets the sender_rfc of this CepResponse.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) del emisor.  # noqa: E501

        :return: The sender_rfc of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._sender_rfc

    @sender_rfc.setter
    def sender_rfc(self, sender_rfc):
        """Sets the sender_rfc of this CepResponse.

        Es el Registro Federal de Contribuyentes (RFC) del emisor.  # noqa: E501

        :param sender_rfc: The sender_rfc of this CepResponse.  # noqa: E501
        :type: str
        """

        self._sender_rfc = sender_rfc

    @property
    def signature(self):
        """Gets the signature of this CepResponse.  # noqa: E501

        Firma del CEP..  # noqa: E501

        :return: The signature of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this CepResponse.

        Firma del CEP..  # noqa: E501

        :param signature: The signature of this CepResponse.  # noqa: E501
        :type: str
        """

        self._signature = signature

    @property
    def url_zip(self):
        """Gets the url_zip of this CepResponse.  # noqa: E501

        La url al archivo zip del CEP, el cual contiene el xml y pdf  # noqa: E501

        :return: The url_zip of this CepResponse.  # noqa: E501
        :rtype: str
        """
        return self._url_zip

    @url_zip.setter
    def url_zip(self, url_zip):
        """Sets the url_zip of this CepResponse.

        La url al archivo zip del CEP, el cual contiene el xml y pdf  # noqa: E501

        :param url_zip: The url_zip of this CepResponse.  # noqa: E501
        :type: str
        """

        self._url_zip = url_zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CepResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CepResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ContactRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'company': 'str',
        'contact_person': 'str',
        'email': 'str',
        'phone_number': 'str'
    }

    attribute_map = {
        'address': 'address',
        'company': 'company',
        'contact_person': 'contact_person',
        'email': 'email',
        'phone_number': 'phone_number'
    }

    def __init__(self, address=None, company=None, contact_person=None, email=None, phone_number=None):  # noqa: E501
        """ContactRequest - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._company = None
        self._contact_person = None
        self._email = None
        self._phone_number = None
        self.discriminator = None
        if address is not None:
            self.address = address
        if company is not None:
            self.company = company
        if contact_person is not None:
            self.contact_person = contact_person
        self.email = email
        self.phone_number = phone_number

    @property
    def address(self):
        """Gets the address of this ContactRequest.  # noqa: E501

        Es la dirección del contacto, por ejemplo: Calle fulanita No. 500 int 2, Col. Conocida.  # noqa: E501

        :return: The address of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this ContactRequest.

        Es la dirección del contacto, por ejemplo: Calle fulanita No. 500 int 2, Col. Conocida.  # noqa: E501

        :param address: The address of this ContactRequest.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def company(self):
        """Gets the company of this ContactRequest.  # noqa: E501

        Es el nombre de la empresa.  # noqa: E501

        :return: The company of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this ContactRequest.

        Es el nombre de la empresa.  # noqa: E501

        :param company: The company of this ContactRequest.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def contact_person(self):
        """Gets the contact_person of this ContactRequest.  # noqa: E501

        Es el nombre completo de la persona quién será contactada.  # noqa: E501

        :return: The contact_person of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._contact_person

    @contact_person.setter
    def contact_person(self, contact_person):
        """Sets the contact_person of this ContactRequest.

        Es el nombre completo de la persona quién será contactada.  # noqa: E501

        :param contact_person: The contact_person of this ContactRequest.  # noqa: E501
        :type: str
        """

        self._contact_person = contact_person

    @property
    def email(self):
        """Gets the email of this ContactRequest.  # noqa: E501

        Es el correo electrónico (email) de la persona. Se valida que tenga el formato de email, por ejemplo: correo@correo.com.  # noqa: E501

        :return: The email of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ContactRequest.

        Es el correo electrónico (email) de la persona. Se valida que tenga el formato de email, por ejemplo: correo@correo.com.  # noqa: E501

        :param email: The email of this ContactRequest.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def phone_number(self):
        """Gets the phone_number of this ContactRequest.  # noqa: E501

        Es el número de teléfono de la persona. Se validan que sean 10 dígitos del número.  # noqa: E501

        :return: The phone_number of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ContactRequest.

        Es el número de teléfono de la persona. Se validan que sean 10 dígitos del número.  # noqa: E501

        :param phone_number: The phone_number of this ContactRequest.  # noqa: E501
        :type: str
        """
        if phone_number is None:
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContactRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
